<?xml version="1.0" ?><!DOCTYPE TS><TS language="bg" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="62"/>
        <source>Dark theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="88"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin Мениджър на пакети</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="293"/>
        <source>Bulk Install</source>
        <translation>Групова инсталация</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Инсталацията е неуспешна, моля, проверете вашата връзка към мрежата</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Инсталацията е неуспешна, моля, проверете за обновление в контролния център</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Инсталацията е неуспешна, няма достатъчно място на диска</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Инсталацията е неуспешна</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Счупени зависимости: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>Неподходяща архитектура на пакета</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="52"/>
        <source>Drag and drop file here</source>
        <translation>Издърпайте и поставете файла тук</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="76"/>
        <source>Select File</source>
        <translation>Избор на файл</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Сриване</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Показване на подробности</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Инсталиране</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation>Завършено</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="111"/>
        <source>Installing</source>
        <translation>Инсталиране</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="115"/>
        <source>Installed</source>
        <translation>Инсталирано</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="119"/>
        <source>Failed</source>
        <translation>Неуспешно</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="144"/>
        <source>Same version installed</source>
        <translation>Същата версия е инсталирана</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="147"/>
        <source>Other version installed: %1</source>
        <translation>Инсталирана е друга версия: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Collapse</source>
        <translation>Сриване</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Display details</source>
        <translation>Показване на подробности</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="141"/>
        <source>Install</source>
        <translation>Инсталиране</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="143"/>
        <source>Remove</source>
        <translation>Премахване</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="145"/>
        <source>Reinstall</source>
        <translation>Преинсталиране</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="147"/>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="149"/>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="151"/>
        <source>Done</source>
        <translation>Завършено</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="164"/>
        <source>Version: </source>
        <translation>Версия:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="320"/>
        <source>Installed successfully</source>
        <translation>Инсталирането е успешно</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="322"/>
        <source>Uninstalled successfully</source>
        <translation>Деинсталирането е успешно</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="389"/>
        <source>Other version installed: %1</source>
        <translation>Инсталирана е друга версия: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="333"/>
        <source>Uninstall Failed</source>
        <translation>Деинсталирането е неуспешно</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="159"/>
        <source>Name: </source>
        <translation>Име:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="387"/>
        <source>Same version installed</source>
        <translation>Същата версия е инсталирана</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Покажи свързаните пакети</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Сриване</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Потвърждение</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin Инсталатор на пакети</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is used to help users install and remove local packages, supporting bulk install.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>